@@ -8,6 +8,8 @@ class FIFOCache:
         # Initialize all variable
         self.capacity = capacity
         self.map = {}
+        self.hits=0
+        self.misses=0
         self.verdata=Verbose(verbose)
         self.verbose=verbose
         self.list=dll()
@@ -23,6 +25,10 @@ class FIFOCache:
                 node = self.map[key]
                 result = node.val
             self.verdata.get_data(key,result,self.list.head)
+            if result==-1:
+                self.misses+=1
+            else:
+                self.hits+=1
             return result
 
     # This method works in O(1)
@@ -42,6 +48,6 @@ class FIFOCache:
             self.verdata.set_data(key,value,self.list.head)
     
     def get_info(self):
-        return self.verdata.info()
+        print("Cache hits: {} , Cache misses: {}".format(self.hits,self.misses))
 
 
