@@ -9,6 +9,8 @@ class LRUCache:
         # Initialize all variable
         self.capacity = capacity
         self.map = {}
+        self.hits=0
+        self.misses=0
         self.verdata=Verbose(verbose)
         self.verbose=verbose
         self.list=dll()
@@ -25,8 +27,11 @@ class LRUCache:
                 result = node.val
                 self.list.deleteNode(node)
                 self.map[key]=self.list.addToHead(key,result)
-                return result
             self.verdata.get_data(key,result,self.list.head)
+            if result==-1:
+                self.misses+=1
+            else:
+                self.hits+=1
             return result
 
     # This method works in O(1)
@@ -48,7 +53,7 @@ class LRUCache:
             self.verdata.set_data(key,value,self.list.head)
 
     def get_info(self):
-        return self.verdata.info()
+        print("Cache hits: {} , Cache misses: {}".format(self.hits,self.misses))
 
 
 
