@@ -4,8 +4,6 @@ class Verbose:
 
     def __init__(self, verbose=0,info=False):
         self.verbose=verbose
-        self.hits=0
-        self.misses=0
         self.list=dll()
 
     
@@ -13,10 +11,8 @@ class Verbose:
         if self.verbose>0:
             if value==-1:
                 print("Did'nt find any value for {}".format(key))
-                self.misses+=1
             else:
                 print('Got the value : {} for the key: {}'.format(value, key))
-                self.hits+=1
         if self.verbose==2:
             self.list.printlist(head)
 
@@ -26,8 +22,6 @@ class Verbose:
         if self.verbose==2:
             self.list.printlist(head)
             
-    def info(self):
-        print("Cache hits: {} , Cache misses: {}".format(self.hits,self.misses))
 
 
 
