@@ -1,7 +1,7 @@
 from cacheall.EvictionPolicies.LRUevictionpolicy import LRUCache
 from cacheall.EvictionPolicies.LIFOevictionpolicy import LIFOCache
 from cacheall.EvictionPolicies.FIFOevictionpolicy import FIFOCache
-from dictionary import dict
+from .dictionary import dict
 import threading
 import time
 
